<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Image Viewer</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versione:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>immagine</translation>
    </message>
    <message>
        <source>images</source>
        <translation>immagini</translation>
    </message>
    <message>
        <source>album</source>
        <translation>album</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>albums</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Gestisci sincronizzazione</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sincronizzazione:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuovo album</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Senza nome</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Importati di recente</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Le mie preferite</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Sicuro di voler eliminare questo album?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Le mie preferite</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Timeline</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Puoi aggiungere la cartella da sincronizzare o effettuare il drag&amp;drop delle immagini nella timeline</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Senza nome</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Image Viewer</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Immagini</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Sicuro di voler aggiungere le immagini all&apos;album?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Sincronizza e crea</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Sincronizza</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Sicuro di voler aggiungere la lista e creare l&apos;album rinominandolo?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Esportazione riuscita</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Esportazione fallita</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Sicuro di voler eliminare le immagini?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Info immagine</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Questo file contiene più pagine, utilizza Evince per visualizzarle tutte.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Rimuovi dall&apos;album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Elimina dai preferiti</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ruota in senso orario</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ruota in senso antiorario</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Imposta come wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizza nel file manager</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info immagine</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Puoi aggiungere la cartella da sincronizzare o effettuare il drag&amp;drop delle immagini nella timeline</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Aggiungi ad un album esistente</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Aggiungi in un nuovo album</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Apri cartella</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Non hai i permessi per visualizzare l&apos;immagine</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data modifica</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Dimensione file</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Spettro colore</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Modalità esposizione</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programma esposizione</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tempo esposizione</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Lunghezza focale</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Apertura massima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Metodo di misurazione</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Bilanciamento bianco</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensazione flash</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modello device</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modello lente</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data individuata</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Nessuna scala</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Riempi la pagina</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Riempi la pagina</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Scala: </translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimetri</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimetri</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Pollici</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Posizione immagine</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Scala</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Impostazioni immagine</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Impostazioni immagine</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Oscuramento</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Switcher</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Sliding</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Ring</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Seleziona cartella</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Questa cartella non può esser sincronizzata</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Aggiungi cartella</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Gestione sincronizzazione cartella</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>La lista della cartella è vuota</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Cancella sincronizzazione</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Il dispositivo è stato rimosso</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Questa cartella non esiste più</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Calcolo in corso...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visualizzazione immagine</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Termina presentazione</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Rimuovi dall&apos;album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Elimina dai preferiti</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ruota in senso orario</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ruota in senso antiorario</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Imposta come sfondo</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizza nel file manager</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info immagine</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Successiva</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Immagine precedente</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Prossima immagine</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuovo album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Visualizza scorciatoie</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Inserisci una nuova scorciatoia</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Visualizza immagine</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Ripristina predefiniti</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Termina presentazione</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Rimuovi dall&apos;album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Elimina dai preferiti</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ruota in senso orario</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ruota in senso antiorario</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Imposta come wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizza nel file manager</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info immagine</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nuovo album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Termina presentazione</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pausa/Avvia</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Impostazioni slide</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Effetto transizione</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durata</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Durata transizione</translation>
    </message>
    <message>
        <source>second</source>
        <translation>secondi</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Gestione immagine</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Le mie preferite</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Scala 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Adatta alla finestra</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ruota in senso antiorario</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ruota in senso orario</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Rimuovi dai preferiti</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Aggiungi ai preferiti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>File immagine non trovato</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Apri immagine</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 immagine</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 immagini</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Gestisci sincronizzazione</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sincronizzazione:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Puoi aggiungere la cartella da sincronizzare o effettuare il drag&amp;drop delle immagini nella timeline</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Aggiungi ad un album esistente</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Aggiungi in un nuovo album</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copia negli appunti</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Elimina dai preferiti</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ruota in senso orario</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ruota in senso antiorario</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Imposta come sfondo</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizza nel file manager</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info immagine</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Impostazioni slide</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Effetto</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durata</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Le mie preferite</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Importati di recente</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nuovo album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Deepin Image Viewer è un gestore immagini bello e veloce.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Fornisce una gestione delle immagini, la loro visualizzazione ed un editing base.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema scuro</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Deepin Image Viewer è un gestore di immagini elegante e veloce.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Timeline</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Aggiungi ad un album esistente</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Aggiungi in un nuovo album</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Esci dalla modalità schermo interno</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Schermo interno</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentazione</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Rimuovi dall&apos;album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Preferita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Elimina dai preferiti</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostra finestra di navigazione</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Nascondi finestra di navigazione</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Ruota in senso orario</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Ruota in senso antiorario</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Imposta come wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Visualizza nel file manager</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Info immagine</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Apri immagine</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Tutte le immagini</translation>
    </message>
</context>
</TS>